@@ -5,10 +5,12 @@ use warnings FATAL => 'all';
 
 BEGIN {
   *_PERL_LT_5_8_4 = ($] < 5.008004) ? sub(){1} : sub(){0};
-  *_CAN_GOTO_VERSION = ($] >= 5.008000) ? sub(){1} : sub(){0};
+  # goto &UNIVERSAL::VERSION usually works on 5.8, but fails on some ARM
+  # machines.  Seems to always work on 5.10 though.
+  *_CAN_GOTO_VERSION = ($] >= 5.010000) ? sub(){1} : sub(){0};
 }
 
-our $VERSION = '2.000000';
+our $VERSION = '2.000001';
 $VERSION = eval $VERSION;
 
 our @WARNING_CATEGORIES = grep { exists $warnings::Offsets{$_} } qw(
@@ -18,6 +20,7 @@ our @WARNING_CATEGORIES = grep { exists $warnings::Offsets{$_} } qw(
   exiting
   experimental
     experimental::autoderef
+    experimental::bitwise
     experimental::const_attr
     experimental::lexical_subs
     experimental::lexical_topic
@@ -197,9 +200,9 @@ sub _want_extra {
     and $file =~ /^(?:t|xt|lib|blib)[\\\/]/
     and defined $Smells_Like_VCS ? $Smells_Like_VCS
       : ( $Smells_Like_VCS = !!(
-        -e '.git' || -e '.svn' || -e '.hg'
+        -e '.git' || -e '.svn' || -e '.hg' || -e '.bzr'
         || (-e '../../dist.ini'
-          && (-e '../../.git' || -e '../../.svn' || -e '../../.hg' ))
+          && (-e '../../.git' || -e '../../.svn' || -e '../../.hg' || -e '../../.bzr' ))
       ))
   );
 }
@@ -243,7 +246,7 @@ EOE
 __END__
 =head1 NAME
 
-strictures - turn on strict and make all warnings fatal
+strictures - turn on strict and make most warnings fatal
 
 =head1 SYNOPSIS
 
@@ -269,12 +272,12 @@ except when called from a file which matches:
 
   (caller)[1] =~ /^(?:t|xt|lib|blib)[\\\/]/
 
-and when either C<.git>, C<.svn>, or C<.hg> is present in the current directory
-(with the intention of only forcing extra tests on the author side) -- or when
-C<.git>, C<.svn>, or C<.hg> is present two directories up along with
-C<dist.ini> (which would indicate we are in a C<dzil test> operation, via
-L<Dist::Zilla>) -- or when the C<PERL_STRICTURES_EXTRA> environment variable is
-set, in which case it also does the equivalent of
+and when either C<.git>, C<.svn>, C<.hg>, or C<.bzr> is present in the current
+directory (with the intention of only forcing extra tests on the author side)
+-- or when C<.git>, C<.svn>, C<.hg>, or C<.bzr> is present two directories up
+along with C<dist.ini> (which would indicate we are in a C<dzil test> operation,
+via L<Dist::Zilla>) -- or when the C<PERL_STRICTURES_EXTRA> environment variable
+is set, in which case it also does the equivalent of
 
   no indirect 'fatal';
   no multidimensional;
